==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elk/dialogs_en.lua <==

dialogId("deu-m-valka", "font_small", "The war goes on even here, on the ocean floor.")

dialogId("deu-v-nepratelstvi", "font_big", "The hostility will never ebb.")

dialogId("deu-m-bojovat", "font_small", "They will fight to the last... parrot.")

dialogId("deu-v-losa", "font_big", "And elk.")

dialogId("deu-m-zvlastni", "font_small", "Now, this is strange. I thought that elks only live in Sweden.")

dialogId("deu-v-slysel", "font_big", "Yes. I too have heard that they bite tourists there.")

dialogId("deu-l-los", "font_elk", "Ya rusky los.")

dialogId("deu-v-radsi", "font_big", "I`d like this elk much more if it wasn`t blocking our way so much.")

dialogId("deu-l-pozalsta", "font_elk", "Pozhalsta, izvinitye.")

dialogId("deu-p-schnell", "font_parrot", "Schnell, schnell.")

dialogId("deu-p-los", "font_parrot", "Was ist denn los?")

dialogId("deu-l-los0", "font_elk", "Ja los!")

dialogId("deu-l-los1", "font_elk", "Chto sluchilos?")

dialogId("deu-p-jawohl", "font_parrot", "Jawohl, mein Herr!")

dialogId("deu-p-stimmt", "font_parrot", "Das stimmt, mein Herr!")

dialogId("deu-p-streng", "font_parrot", "Streng geheim!")

dialogId("deu-p-ordnung", "font_parrot", "Das ist in Ordnung, Herr Oberleutnant!")

dialogId("deu-p-skoll", "font_parrot", "Skål!")

dialogId("deu-p-trinken0", "font_parrot", "Guten Morgen, mein Herr! Wollen Sie noch einen Tee?")

dialogId("deu-p-trinken1", "font_parrot", "Guten Tag, mein Herr! Wollen Sie etwas trinken?")

dialogId("deu-l-ja", "font_elk", "Ya los...")

dialogId("deu-l-neznaju", "font_elk", "Ya nichevo nyeznayu.")

dialogId("deu-l-nesmotrel", "font_elk", "Ya nichevo nyesmotrel.")

dialogId("deu-l-zivjot", "font_elk", "Pustye zhivyot moguchy Sovietsky Soyuz!")

dialogId("deu-l-necital", "font_elk", "Ja nichevo nechital.")

dialogId("deu-l-tovarisci", "font_elk", "Tovarishchi, bratya i sestri, dorogiye druzya...")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/elk/dialogs_en.lua <==

dialogId("deu-m-valka", "font_small", "The war goes on even here, on the ocean floor.")

dialogId("deu-v-nepratelstvi", "font_big", "The hostility will never ebb.")

dialogId("deu-m-bojovat", "font_small", "They will fight to the last... parrot.")

dialogId("deu-v-losa", "font_big", "And elk.")

dialogId("deu-m-zvlastni", "font_small", "Now, this is strange. I thought that elks only live in Sweden.")

dialogId("deu-v-slysel", "font_big", "Yes. I too have heard that they bite tourists there.")

dialogId("deu-l-los", "font_elk", "Ya rusky los.")

dialogId("deu-v-radsi", "font_big", "I’d like this elk much more if it wasn’t blocking our way so much.")

dialogId("deu-l-pozalsta", "font_elk", "Pozhalsta, izvinitye.")

dialogId("deu-p-schnell", "font_parrot", "Schnell, schnell.")

dialogId("deu-p-los", "font_parrot", "Was ist denn los?")

dialogId("deu-l-los0", "font_elk", "Ja los!")

dialogId("deu-l-los1", "font_elk", "Chto sluchilos?")

dialogId("deu-p-jawohl", "font_parrot", "Jawohl, mein Herr!")

dialogId("deu-p-stimmt", "font_parrot", "Das stimmt, mein Herr!")

dialogId("deu-p-streng", "font_parrot", "Streng geheim!")

dialogId("deu-p-ordnung", "font_parrot", "Das ist in Ordnung, Herr Oberleutnant!")

dialogId("deu-p-skoll", "font_parrot", "Skål!")

dialogId("deu-p-trinken0", "font_parrot", "Guten Morgen, mein Herr! Wollen Sie noch einen Tee?")

dialogId("deu-p-trinken1", "font_parrot", "Guten Tag, mein Herr! Wollen Sie etwas trinken?")

dialogId("deu-l-ja", "font_elk", "Ya los...")

dialogId("deu-l-neznaju", "font_elk", "Ya nichevo nyeznayu.")

dialogId("deu-l-nesmotrel", "font_elk", "Ya nichevo nyesmotrel.")

dialogId("deu-l-zivjot", "font_elk", "Pustye zhivyot moguchy Sovietsky Soyuz!")

dialogId("deu-l-necital", "font_elk", "Ja nichevo nechital.")

dialogId("deu-l-tovarisci", "font_elk", "Tovarishchi, bratya i sestri, dorogiye druzya...")
